@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,7 +54,7 @@ using namespace studio;
 /* === M E T H O D S ======================================================= */
 
 Dialog_ToolOptions::Dialog_ToolOptions():
-	Dockable("tool_options",_("Tool Options"),Gtk::StockID("synfig-normal")),
+	Dockable("tool_options",_("Tool Options"),Gtk::StockID("synfig-about")),
 	empty_label(_("This tool has no options"))
 {
 	//scrolled_.add(sub_vbox_);
@@ -80,7 +81,7 @@ Dialog_ToolOptions::clear()
 	set_widget(empty_label);
 	empty_label.show();
 
-	set_stock_id(Gtk::StockID("synfig-normal"));
+	set_stock_id(Gtk::StockID("synfig-about"));
 }
 
 void
