@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -217,13 +218,16 @@ public:
 	synfig::Point get_point()const { return shared_point?*shared_point:point; }
 
 	synfig::Angle get_rotations()const { return rotations; };
+	void set_rotations(const synfig::Angle &x) { rotations=x; };
 
 	synfig::Point get_trans_point()const;
 
 	void set_trans_point(const synfig::Point &x);
+	void set_trans_point(const synfig::Point &x, const synfig::Time &time);
 
 	synfig::Point get_sub_trans_point()const;
 	void set_sub_trans_point(const synfig::Point &x);
+	void set_sub_trans_point(const synfig::Point &x, const synfig::Time &time);
 	synfig::Point get_sub_trans_origin()const;
 
 	//! Sets the origin point.
