@@ -10,6 +10,7 @@
 **  Copyright (c) 2008 Paul Wise
 **  Copyright (c) 2009 Gerco Ballintijn
 **	Copyright (c) 2009 Carlos López
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -160,9 +161,44 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(canvas_pointer,"canvas_pointer_icon."IMAGE_EXT,_("Rename"));
 	INIT_STOCK_ICON(canvas_new,"canvas_icon."IMAGE_EXT,_("New Canvas"));
 	INIT_STOCK_ICON(saveall,"saveall_icon."IMAGE_EXT,_("Save All"));
+
 	INIT_STOCK_ICON(layer,"layer_icon."IMAGE_EXT,_("Layer"));
 	INIT_STOCK_ICON(layer_pastecanvas,"pastecanvas_icon."IMAGE_EXT,_("Paste Canvas"));
+	INIT_STOCK_ICON(layer_duplicate,"layer_duplicate_icon."IMAGE_EXT,_("Duplicate Layer"));
+	INIT_STOCK_ICON(layer_gradient_lineal,"gradient_icon."IMAGE_EXT,_("Lineal Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_radial,"layer_gradient_radial_icon."IMAGE_EXT,_("Radial Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_spiral,"layer_gradient_spiral_icon."IMAGE_EXT,_("Spiral Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_curve,"layer_gradient_curve_icon."IMAGE_EXT,_("Curve Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_conical,"layer_gradient_conical_icon."IMAGE_EXT,_("Conical Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_noise,"layer_gradient_noise_icon."IMAGE_EXT,_("Noise Gradient Layer"));
+	INIT_STOCK_ICON(layer_checkerboard,"layer_checkerboard_icon."IMAGE_EXT,_("Checker Board Layer"));
+	INIT_STOCK_ICON(layer_blur,"layer_blur_icon."IMAGE_EXT,_("Blur Layer"));
+	INIT_STOCK_ICON(layer_blur_motion,"layer_blur_motion_icon."IMAGE_EXT,_("Motion Blur Layer"));
+	INIT_STOCK_ICON(layer_blur_radial,"layer_blur_radial_icon."IMAGE_EXT,_("Radial Blur Layer"));
+	INIT_STOCK_ICON(layer_distortion_curvewarp,"layer_distortion_curvewarp_icon."IMAGE_EXT,_("Curve Warp Layer"));
+	INIT_STOCK_ICON(layer_distortion_insideout,"layer_distortion_insideout_icon."IMAGE_EXT,_("Inside Out Layer"));
+	INIT_STOCK_ICON(layer_distortion_noise,"layer_distortion_noise_icon."IMAGE_EXT,_("Noise Distort Layer"));
+	INIT_STOCK_ICON(layer_distortion_spherize,"layer_distortion_spherize_icon."IMAGE_EXT,_("Spherize Layer"));
+	INIT_STOCK_ICON(layer_distortion_stretch,"layer_distortion_stretch_icon."IMAGE_EXT,_("Stretch Layer"));
+	INIT_STOCK_ICON(layer_distortion_twirl,"layer_distortion_twirl_icon."IMAGE_EXT,_("Twirl Layer"));
+	INIT_STOCK_ICON(layer_distortion_warp,"layer_distortion_warp_icon."IMAGE_EXT,_("Warp Layer"));
+	INIT_STOCK_ICON(layer_filter_clamp,"layer_filter_clamp_icon."IMAGE_EXT,_("Clamp Layer"));
+	INIT_STOCK_ICON(layer_filter_colorcorrect,"layer_filter_colorcorrect_icon."IMAGE_EXT,_("Color Correct Layer"));
+	INIT_STOCK_ICON(layer_filter_halftone2,"layer_filter_halftone2_icon."IMAGE_EXT,_("Half Tone 2 Layer"));
+	INIT_STOCK_ICON(layer_filter_halftone3,"layer_filter_halftone3_icon."IMAGE_EXT,_("Half Tone 3 Layer"));
+	INIT_STOCK_ICON(layer_filter_luma,"layer_filter_luma_icon."IMAGE_EXT,_("Luma Layer"));
+	INIT_STOCK_ICON(layer_fractal_mandelbrot,"layer_fractal_mandelbrot_icon."IMAGE_EXT,_("Mandelbrot Set Layer"));
+	INIT_STOCK_ICON(layer_fractal_julia,"layer_fractal_julia_icon."IMAGE_EXT,_("Julia Set Layer"));
+	INIT_STOCK_ICON(layer_stylize_bevel,"layer_stylize_bevel_icon."IMAGE_EXT,_("Bevel Layer"));
+	INIT_STOCK_ICON(layer_stylize_shade,"layer_stylize_shade_icon."IMAGE_EXT,_("Shade Layer"));
+	INIT_STOCK_ICON(layer_example_metaballs,"layer_example_metaballs_icon."IMAGE_EXT,_("Metaballs Layer"));
+	INIT_STOCK_ICON(layer_other_XOR,"layer_other_XOR_icon."IMAGE_EXT,_("XOR Pattern Layer"));
+	INIT_STOCK_ICON(layer_other_supersample,"layer_other_supersample_icon."IMAGE_EXT,_("Super Sample Layer"));
+	INIT_STOCK_ICON(layer_other_timeloop,"layer_other_timeloop_icon."IMAGE_EXT,_("Time Loop Layer"));
+	INIT_STOCK_ICON(layer_transform_translate,"layer_transform_translate_icon."IMAGE_EXT,_("Translate Layer"));
+
 	INIT_STOCK_ICON(plant,"plant_icon."IMAGE_EXT,"");
+
 	INIT_STOCK_ICON(group,"group_icon."IMAGE_EXT,_("Group"));
 	INIT_STOCK_ICON(grid_enable,"grid_enable_icon."IMAGE_EXT,_("Show Grid"));
 	INIT_STOCK_ICON(grid_disable,"grid_disable_icon."IMAGE_EXT,_("Hide Grid"));
@@ -194,6 +230,11 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(seek_prev_frame,"seek_prev_frame."IMAGE_EXT,_("Previous Frame"));
 	INIT_STOCK_ICON(seek_next_frame,"seek_next_frame."IMAGE_EXT,_("Next Frame"));
 	INIT_STOCK_ICON(seek_end,"seek_end."IMAGE_EXT,_("Seek to End"));
+	INIT_STOCK_ICON(add_to_group,"action_add_to_group_icon."IMAGE_EXT,_("Add Layer to Group"));
+	INIT_STOCK_ICON(remove_from_group,"action_remove_from_group_icon."IMAGE_EXT,_("Remove Layer from Group"));
+	INIT_STOCK_ICON(set_desc,"action_set_layer_description_icon."IMAGE_EXT,_("Set Layer Description"));
+	INIT_STOCK_ICON(export,"action_export_icon."IMAGE_EXT,_("Export Value Node"));
+	INIT_STOCK_ICON(unexport,"action_unexport_icon."IMAGE_EXT,_("Unexport Value Node"));
 
 	INIT_STOCK_ICON(toggle_duck_position,"duck_position_icon."IMAGE_EXT,_("Toggle position ducks"));
 	INIT_STOCK_ICON(toggle_duck_vertex,"duck_vertex_icon."IMAGE_EXT,_("Toggle vertex ducks"));
@@ -219,7 +260,8 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON_CLONE(cvs_revert,"gtk-revert",_("CVS Revert"));
 
 	// Tools
-	INIT_STOCK_ICON(normal,"normal_icon."IMAGE_EXT,_("Normal Tool"));
+	INIT_STOCK_ICON(normal,"normal_icon."IMAGE_EXT,_("Transform Tool"));
+	INIT_STOCK_ICON(transform,"transform_icon."IMAGE_EXT,_("Transform Tool"));
 	INIT_STOCK_ICON(polygon,"polyline_icon."IMAGE_EXT,_("Polygon Tool"));
 	INIT_STOCK_ICON(bline,"bline_icon."IMAGE_EXT,_("BLine Tool"));
 	INIT_STOCK_ICON(eyedrop,"eyedrop_icon."IMAGE_EXT,_("Eyedrop Tool"));
@@ -229,9 +271,9 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(circle,"circle_icon."IMAGE_EXT,_("Circle Tool"));
 	INIT_STOCK_ICON(rectangle,"rectangle_icon."IMAGE_EXT,_("Rectangle Tool"));
 	INIT_STOCK_ICON(smooth_move,"smooth_move_icon."IMAGE_EXT,_("SmoothMove Tool"));
-	INIT_STOCK_ICON(scale,"scale_icon."IMAGE_EXT,_("Scale Tool"));
+	INIT_STOCK_ICON(rotate,"rotate_icon."IMAGE_EXT,"Rotate Tool");
 	INIT_STOCK_ICON(width,"width_icon."IMAGE_EXT,_("Width Tool"));
-	INIT_STOCK_ICON(rotate,"rotate_icon."IMAGE_EXT,_("Rotate Tool"));
+	INIT_STOCK_ICON(scale,"scale_icon."IMAGE_EXT,"Scale Tool");
 	INIT_STOCK_ICON(zoom,"zoom_icon."IMAGE_EXT,_("Zoom Tool"));
 	INIT_STOCK_ICON(info,"info_icon."IMAGE_EXT,_("Info Tool"));
 	INIT_STOCK_ICON(mirror,"mirror_icon."IMAGE_EXT,_("Mirror Tool"));
@@ -427,8 +469,74 @@ studio::layer_icon(const synfig::String &layer)
 		return Gtk::StockID("synfig-plant");
 	else if(layer=="text")
 		return Gtk::StockID("synfig-text");
-	else if(layer.find("gradient")!=String::npos)
-		return Gtk::StockID("synfig-gradient");
+	else if(layer=="checker_board")
+		return Gtk::StockID("synfig-layer_checkerboard");
+	else if(layer=="duplicate")
+		return Gtk::StockID("synfig-layer_duplicate");
+	else if(layer=="linear_gradient")
+		return Gtk::StockID("synfig-layer_gradient_lineal");
+	else if(layer=="radial_gradient")
+		return Gtk::StockID("synfig-layer_gradient_radial");
+	else if(layer=="spiral_gradient")
+		return Gtk::StockID("synfig-layer_gradient_spiral");
+	else if(layer=="curve_gradient")
+		return Gtk::StockID("synfig-layer_gradient_curve");
+	else if(layer=="conical_gradient")
+		return Gtk::StockID("synfig-layer_gradient_conical");
+	else if(layer=="noise")
+		return Gtk::StockID("synfig-layer_gradient_noise");
+	else if(layer=="blur")
+		return Gtk::StockID("synfig-layer_blur");
+	else if(layer=="radial_blur")
+		return Gtk::StockID("synfig-layer_blur_radial");
+	else if(layer=="MotionBlur") // in the future should be "motion_blur"
+		return Gtk::StockID("synfig-layer_blur_motion");
+	else if(layer=="curve_warp")
+		return Gtk::StockID("synfig-layer_distortion_curvewarp");
+	else if(layer=="inside_out")
+		return Gtk::StockID("synfig-layer_distortion_insideout");
+	else if(layer=="noise_distort")
+		return Gtk::StockID("synfig-layer_distortion_noise");
+	else if(layer=="spherize")
+		return Gtk::StockID("synfig-layer_distortion_spherize");
+	else if(layer=="stretch")
+		return Gtk::StockID("synfig-layer_distortion_stretch");
+	else if(layer=="twirl")
+		return Gtk::StockID("synfig-layer_distortion_twirl");
+	else if(layer=="warp")
+		return Gtk::StockID("synfig-layer_distortion_warp");
+	else if(layer=="clamp")
+		return Gtk::StockID("synfig-layer_filter_clamp");
+	else if(layer=="colorcorrect")
+		return Gtk::StockID("synfig-layer_filter_colorcorrect");
+	else if(layer=="halftone2")
+		return Gtk::StockID("synfig-layer_filter_halftone2");
+	else if(layer=="halftone3")
+		return Gtk::StockID("synfig-layer_filter_halftone3");
+	else if(layer=="lumakey")
+		return Gtk::StockID("synfig-layer_filter_luma");
+	else if(layer=="mandelbrot")
+		return Gtk::StockID("synfig-layer_fractal_mandelbrot");
+	else if(layer=="julia")
+		return Gtk::StockID("synfig-layer_fractal_julia");
+	else if(layer=="bevel")
+		return Gtk::StockID("synfig-layer_stylize_bevel");
+	else if(layer=="shade")
+		return Gtk::StockID("synfig-layer_stylize_shade");
+	else if(layer=="metaballs")
+		return Gtk::StockID("synfig-layer_example_metaballs");
+	else if(layer=="simple_circle")
+		return Gtk::StockID("synfig-circle");
+	else if(layer=="filled_rectangle")
+		return Gtk::StockID("synfig-rectangle");
+	else if(layer=="xor_pattern")
+		return Gtk::StockID("synfig-layer_other_XOR");
+	else if(layer=="super_sample")
+		return Gtk::StockID("synfig-layer_other_supersample");
+	else if(layer=="timeloop")
+		return Gtk::StockID("synfig-layer_other_timeloop");
+	else if(layer=="translate")
+		return Gtk::StockID("synfig-layer_transform_translate");
 	else
 		return Gtk::StockID("synfig-layer");
 }
