@@ -7,7 +7,8 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**  Copyright (c) 2008 Carlos López
+**	Copyright (c) 2008 Carlos López
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -1024,7 +1025,8 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 		param_list2=canvas_interface->generate_param_list(
 			synfigapp::ValueDesc(
 				ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node())
-				,0
+				,ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node())
+                                                           ->get_link_index_from_name("point")
 			)
 		);
 		param_list2.add("origin",location);
