@@ -30,6 +30,7 @@
 #endif
 
 #include "state_eyedrop.h"
+#include "state_normal.h"
 #include "workarea.h"
 #include <synfig/context.h>
 #include "app.h"
@@ -113,8 +114,10 @@ StateEyedrop_Context::~StateEyedrop_Context()
 Smach::event_result
 StateEyedrop_Context::event_stop_handler(const Smach::event& /*x*/)
 {
-	synfig::info("STATE EYEDROP: Received Stop Event");
-	throw Smach::egress_exception();
+	//synfig::info("STATE EYEDROP: Received Stop Event");
+	//throw Smach::egress_exception();
+	throw &state_normal;
+	return Smach::RESULT_OK;
 //	canvas_view->get_smach().pop_state();
 //	return Smach::RESULT_ACCEPT;
 }
