@@ -37,6 +37,7 @@
 #include <synfigapp/action_system.h>
 
 #include "state_gradient.h"
+#include "state_normal.h"
 #include "canvasview.h"
 #include "workarea.h"
 #include "app.h"
@@ -144,7 +145,7 @@ public:
 	Smach::event_result event_layer_selection_changed_handler(const Smach::event& /*x*/)
 	{
 		if(egress_on_selection_change)
-			throw Smach::egress_exception();
+			throw &state_normal; //throw Smach::egress_exception();
 		return Smach::RESULT_OK;
 	}
 
@@ -297,7 +298,7 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 	// Turn off layer clicking
 	get_work_area()->set_allow_layer_clicks(false);
 
-	get_canvas_view()->work_area->set_cursor(Gdk::CROSSHAIR);
+	get_work_area()->set_cursor(Gdk::CROSSHAIR);
 
 	// clear out the ducks
 	get_work_area()->clear_ducks();
@@ -342,7 +343,7 @@ StateGradient_Context::~StateGradient_Context()
 	// Restore layer clicking
 //	get_work_area()->set_allow_layer_clicks(prev_workarea_layer_status_);
 	get_work_area()->set_allow_layer_clicks(true);
-	get_canvas_view()->work_area->reset_cursor();
+	get_work_area()->reset_cursor();
 
 	App::dialog_tool_options->clear();
 
@@ -367,7 +368,9 @@ StateGradient_Context::~StateGradient_Context()
 Smach::event_result
 StateGradient_Context::event_stop_handler(const Smach::event& /*x*/)
 {
-	throw Smach::egress_exception();
+	//throw Smach::egress_exception();
+	throw &state_normal;
+	return Smach::RESULT_OK;
 }
 
 Smach::event_result
