@@ -8,6 +8,7 @@
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **  Copyright (c) 2008 Paul Wise
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -253,12 +254,18 @@ Toolbox::Toolbox():
 		sigc::ptr_fun(&show_dialog_input)));
 	filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Setup..."),
 		sigc::ptr_fun(&studio::App::show_setup)));
+	filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Reset to default Setup values"),
+		sigc::ptr_fun(&studio::App::reset_initial_preferences)));
 
 	filemenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::StockID(Gtk::Stock::QUIT),
 		sigc::ptr_fun(studio::App::quit)));
 
 #define WIKI(title,page)											\
+	helpmenu->items().push_back(Gtk::Menu_Helpers::MenuElem(title,	\
+		sigc::bind(sigc::ptr_fun(&studio::App::open_url),String("http://synfig.org/wiki")+page)))
+
+#define SITE(title,page)											\
 	helpmenu->items().push_back(Gtk::Menu_Helpers::MenuElem(title,	\
 		sigc::bind(sigc::ptr_fun(&studio::App::open_url),String("http://synfig.org")+page)))
 
@@ -266,14 +273,11 @@ Toolbox::Toolbox():
 	helpmenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::HELP, sigc::ptr_fun(studio::App::dialog_help)));
 	helpmenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
 
-	/* TRANSLATORS: Help menu entry */ WIKI(_("Synfig Wiki"),				/* TRANSLATORS: a wiki page */ _("/Main_Page")				);
-	/* TRANSLATORS: Help menu entry */ WIKI(_("Tutorials"),					/* TRANSLATORS: a wiki page */ _("/Tutorials")				);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Tutorials"),					/* TRANSLATORS: a wiki page */ _("/Category:Tutorials")				);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Reference"),					/* TRANSLATORS: a wiki page */ _("/Category:Reference")				);
 	/* TRANSLATORS: Help menu entry */ WIKI(_("Frequently Asked Questions"),/* TRANSLATORS: a wiki page */ _("/FAQ")					);
-	/* TRANSLATORS: Help menu entry */ WIKI(_("Get Support"),				/* TRANSLATORS: a wiki page */ _("/Contact")			);
-	/* TRANSLATORS: Help menu entry */ WIKI(_("Keyboard Shortcuts"),		/* TRANSLATORS: a wiki page */ _("/Keyboard_Shortcuts")		);
-	/* TRANSLATORS: Help menu entry */ WIKI(_("Mouse Shortcuts"),			/* TRANSLATORS: a wiki page */ _("/Mouse_Shortcuts")		);
-	/* TRANSLATORS: Help menu entry */ WIKI(_("All Pages"), "/Special:Allpages" );
-
+	helpmenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
+	/* TRANSLATORS: Help menu entry */ SITE(_("Get Support"),				/* TRANSLATORS: a website page */ _("/en/support")			);
 	helpmenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
 	helpmenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::StockID("synfig-about"),
 		sigc::ptr_fun(studio::App::dialog_about)));
@@ -312,17 +316,17 @@ Toolbox::Toolbox():
 	// Create the file button cluster
 	Gtk::Table *file_buttons=manage(new class Gtk::Table());
 
-	file_buttons->attach(*button_new,      0,1, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_open,     1,2, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_save,     2,3, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_saveas,   3,4, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_save_all, 4,5, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_new,      0,1, 0,1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_open,     1,2, 0,1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_save,     2,3, 0,1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_saveas,   3,4, 0,1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_save_all, 4,5, 0,1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
 
-	file_buttons->attach(*button_undo,     0,1, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_redo,     1,2, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_setup,    2,3, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_about,    3,4, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_help,     4,5, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_undo,     0,1, 1,2, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_redo,     1,2, 1,2, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_setup,    2,3, 1,2, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_about,    3,4, 1,2, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
+	file_buttons->attach(*button_help,     4,5, 1,2, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
 
 	file_buttons->show();
 
@@ -474,16 +478,7 @@ Toolbox::change_state_(const Smach::state_base *state)
 	{
 		etl::handle<studio::CanvasView> canvas_view(studio::App::get_selected_canvas_view());
 		if(canvas_view)
-		{
-			if(state->get_name()==String("normal"))
-			{
-				canvas_view->get_smach().egress();
-			}
-			else
-			{
 				canvas_view->get_smach().enter(state);
-			}
-		}
 		else
 			refresh();
 	}
@@ -520,7 +515,7 @@ Toolbox::add_state(const Smach::state_base *state)
 	int row=state_button_map.size()/5;
 	int col=state_button_map.size()%5;
 
-	tool_table->attach(*button,col,col+1,row,row+1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	tool_table->attach(*button,col,col+1,row,row+1, Gtk::EXPAND, Gtk::EXPAND, 0, 0);
 
 	state_button_map[name]=button;
 
