@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -157,7 +158,7 @@ Action::BLinePointTangentMerge::prepare()
 
 	action->set_param("canvas",get_canvas());
 	action->set_param("canvas_interface",get_canvas_interface());
-	action->set_param("value_desc",ValueDesc(value_node,3));
+	action->set_param("value_desc",ValueDesc(value_node,value_node->get_link_index_from_name("split")));
 	action->set_param("time",time);
 	action->set_param("new_value",synfig::ValueBase(false));
 
