@@ -2,7 +2,7 @@
 /*!	\file valuedescconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuedescconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -31,6 +31,7 @@
 #endif
 
 #include "layerparamconnect.h"
+#include "waypointconnect.h"
 #include "valuenodelinkconnect.h"
 #include "valuenodereplace.h"
 
@@ -50,13 +51,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescConnect);
-ACTION_SET_NAME(Action::ValueDescConnect,"value_desc_connect");
+ACTION_SET_NAME(Action::ValueDescConnect,"ValueDescConnect");
 ACTION_SET_LOCAL_NAME(Action::ValueDescConnect,N_("Connect"));
 ACTION_SET_TASK(Action::ValueDescConnect,"connect");
 ACTION_SET_CATEGORY(Action::ValueDescConnect,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueDescConnect,0);
 ACTION_SET_VERSION(Action::ValueDescConnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescConnect,"$Id: valuedescconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescConnect,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -200,6 +201,23 @@ Action::ValueDescConnect::prepare()
 		return;
 	}
 	else
+	if(value_desc.parent_is_waypoint())
+	{
+		Action::Handle action(WaypointConnect::create());
+
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",get_canvas_interface());
+		action->set_param("parent_value_node",value_desc.get_parent_value_node());
+		action->set_param("value_node", value_node);
+		action->set_param("waypoint_time",value_desc.get_waypoint_time());
+
+		assert(action->is_ready());
+		if(!action->is_ready())
+			throw Error(Error::TYPE_NOTREADY);
+
+		add_action_front(action);
+		return;
+	}
 	if(value_desc.parent_is_linkable_value_node())
 	{
 		Action::Handle action(ValueNodeLinkConnect::create());
