@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistunloop.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistunloop.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeDynamicListUnLoop);
-ACTION_SET_NAME(Action::ValueNodeDynamicListUnLoop,"value_node_dynamic_list_unloop");
+ACTION_SET_NAME(Action::ValueNodeDynamicListUnLoop,"ValueNodeDynamicListUnLoop");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListUnLoop,N_("Unloop"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListUnLoop,"unloop");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListUnLoop,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListUnLoop,0);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListUnLoop,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListUnLoop,"$Id: valuenodedynamiclistunloop.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListUnLoop,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
